@@ -179,6 +179,11 @@ static void about_cb (GtkWidget *widget, gpointer data)
 	static GtkWidget *about;
 
 	const gchar *authors[] = {"Sean MacIsaac", "Ian Peters", NULL};
+	gchar *documenters[] = {
+                NULL
+        };
+        /* Translator credits */
+        gchar *translator_credits = _("");
 
 	if (about != NULL) {
 		gdk_window_raise (about->window);
@@ -188,9 +193,11 @@ static void about_cb (GtkWidget *widget, gpointer data)
 
 	about = gnome_about_new (_("Gnibbles"), VERSION,
 			"(C) 1999 Sean MacIsaac and Ian Peters",
-			(const char **)authors,
 			_("Send comments and bug reports to: "
 			  "sjm@acm.org, itp@gnu.org"),
+			(const char **)authors,
+			(const char **)documenters,
+                        (const char *)translator_credits,
 			NULL);
 	gtk_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
@@ -253,7 +260,8 @@ static gint configure_event_cb (GtkWidget *widget, GdkEventConfigure *event)
 	int i, j;
 
 	gnibbles_load_pixmap();
-	gdk_imlib_free_pixmap (buffer_pixmap);
+	if (buffer_pixmap)
+		gdk_pixmap_unref (buffer_pixmap);
 	buffer_pixmap = gdk_pixmap_new (drawing_area->window,
 					BOARDWIDTH * properties->tilesize,
 					BOARDHEIGHT * properties->tilesize, -1);
@@ -553,8 +561,8 @@ static void setup_window ()
 	gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 			GTK_SIGNAL_FUNC (quit_cb), NULL);
 
-	gtk_widget_push_visual (gdk_imlib_get_visual ());
-	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+	gtk_widget_push_visual (gdk_rgb_get_visual ());
+	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	drawing_area = gtk_drawing_area_new ();
 
@@ -627,8 +635,9 @@ int main (int argc, char **argv)
 
 	gnome_score_init ("gnibbles");
 
-	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
 	
 	gnome_init ("Gnibbles", VERSION, argc, argv);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-nibbles.png");
